@@ -5,7 +5,7 @@
  * @date 15.02.2017
  * @copyright Apache License v.2 (http://www.apache.org/licenses/LICENSE-2.0)
 */
-
+#include <Rcpp.h>
 #include "word2vec.hpp"
 #include "wordReader.hpp"
 #include "vocabulary.hpp"
@@ -287,7 +287,7 @@ namespace w2v {
         return false;
     }
 
-    doc2vec_t::doc2vec_t(const std::unique_ptr<w2vModel_t> &_model,
+    doc2vec_t::doc2vec_t(const Rcpp::XPtr<w2vModel_t> &_model,
                          const std::string &_doc,
                          const std::string &_wordDelimiterChars): vector_t(_model->vectorSize()) {
         stringMapper_t stringMapper(_doc);
